﻿#
# Upload a file to a ftp-server every time when it gets modified.
#

# Usage
if ($args.Count -ne 4) {
    Write-Output "Usage: upload.ps1 [file] [ftp-server] [ftp-user] [ftp-password]"
    Break
}

# Parameters
$FILE = $args[0]
$SERVER = $args[1]
$USER = $args[2]

# Test whether file exists
if (-NOT (Test-Path -path $FILE)) {
    Write-Output "ERROR: File not found: $FILE"
    Break
}

# Check file type
if (-NOT ($FILE -match ".json$")) {
    Write-Output "ERROR: No *.json file: $FILE"
    Break
}

# Settings (Maximal runtime: 10 hours)
$PAUSE_TIMER = 15
$LOOP_COUNT = 60*60*10 / $PAUSE_TIMER
$LAST_UPLOAD = (Get-Date "03/02/2001 04:05:06")
# $LAST_SIZE = 0

# Show parameters
Write-Output "#######################"
Write-Output "### File=$FILE"
Write-Output "### Server=$SERVER"
Write-Output "### User=$USER"
# Write-Output "### Password=$args[3]" # Skipped due to security reason
Write-Output "### Pause=$PAUSE_TIMER sec"
Write-Output "#######################"

# Create temporary ftp script
$PASSWORD = $args[3]
$null = New-Item upload-ps1.ftp -Force -Value @"
$USER
$PASSWORD
asc
put $FILE
quit
"@
$PASSWORD = ""

for($loop = 0; $loop -lt $LOOP_COUNT; $loop++) {

    # Test whether file exists
    if (-NOT (Test-Path -path $FILE)) {
        Write-Output "ERROR: File does not exist: $FILE"
        Break
    }

    # Get file properties
    $lastModified = (Get-Item $FILE).LastWriteTime
    $size = (Get-Item $FILE).length

    # Test whether size is too large (> 1MB)
    if ($size -gt 1000000) {
        Write-Output "ERROR: File is too large: $size"
        Break
    }

    # Test whether modification date is newer
    if ($lastModified -gt $LAST_UPLOAD) { # }-OR ($size -ne $LAST_SIZE)) {
        # Upload file via ftp
        Write-Output "Upload file on $lastModified"
        $null = ftp -i -v -s:upload-ps1.ftp $SERVER

        # Keep upload status
        $LAST_UPLOAD = $lastModified
        # $LAST_SIZE = $size
    }

    # Pause
    Write-Host "." -NoNewline
    Start-Sleep -Seconds $PAUSE_TIMER
}

# Delete ftp script
Remove-Item upload-ps1.ftp
